[LyX/master] Rename BufferView::updateScrollbar to show what does

Jean-Marc Lasgouttes lasgouttes at lyx.org
Fri Oct 29 15:21:49 UTC 2021


commit 110445e3e2fe9beab1c38d2806cfd126dae967a9
Author: Jean-Marc Lasgouttes <lasgouttes at lyx.org>
Date:   Fri Oct 29 17:44:32 2021 +0200

    Rename BufferView::updateScrollbar to show what does
    
    Only parameters are updated, not the scrollbar itself.
---
 src/BufferView.cpp |    4 ++--
 src/BufferView.h   |    4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/BufferView.cpp b/src/BufferView.cpp
index f7f2d35..e4b7102 100644
--- a/src/BufferView.cpp
+++ b/src/BufferView.cpp
@@ -583,7 +583,7 @@ void BufferView::processUpdateFlags(Update::flags flags)
 }
 
 
-void BufferView::updateScrollbar()
+void BufferView::updateScrollbarParameters()
 {
 	if (height_ == 0 && width_ == 0)
 		return;
@@ -3483,7 +3483,7 @@ void BufferView::draw(frontend::Painter & pain, bool paint_caret)
 
 	// The scrollbar needs an update.
 	// FIXME: does it always? see ticket #11947.
-	updateScrollbar();
+	updateScrollbarParameters();
 
 	// Normalize anchor for next time
 	pair<pit_type, ParagraphMetrics const *> firstpm = tm.first();
diff --git a/src/BufferView.h b/src/BufferView.h
index e831e3a..210200a 100644
--- a/src/BufferView.h
+++ b/src/BufferView.h
@@ -155,8 +155,8 @@ public:
 	int horizScrollOffset(Text const * text,
 	                      pit_type pit, pos_type pos) const;
 
-	/// reset the scrollbar to reflect current view position.
-	void updateScrollbar();
+	/// reset the scrollbar parameters to reflect current view position.
+	void updateScrollbarParameters();
 	/// return the Scrollbar Parameters.
 	ScrollbarParameters const & scrollbarParameters() const;
 	/// \return Tool tip for the given position.


More information about the lyx-cvs mailing list